<?php
/* 
Plugin Name: Comment Houserules
Plugin URI: http://wpmu.org
Description: Allows comments to be marked as broke house rules which means they are still published but content is replaced by broke house rules message. This plugin is heavily based on the Comment Probation plugin by Andrew Nacin (http://nacin.com)
Author: Chris Knowles
Author URI: http://wpmu.org
Version: 0.1
License: GPLv2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
*/

class Plugin_Comment_Houserules {

	const meta_key = '_comment_houserules';	

	function __construct() {
		add_action( 'admin_head-edit-comments.php', array( $this, 'admin_head' ) );
		add_filter( 'comment_row_actions', array( $this, 'comment_row_actions' ), 10, 2 );
		add_action( 'wp_set_comment_status', array( $this, 'wp_set_comment_status' ), 10, 2 );
		add_filter( 'get_comment_text', array( $this, 'get_comment_text'), 10, 2);	
		add_action( 'admin_init', array( $this, 'hr_register_setting' ) );			
	}

	// the comment is being approved check for houserules setting
	function wp_set_comment_status( $comment_id, $status ) {
		
		if ( $status != 'approved' ) 
			delete_comment_meta( $comment_id, self::meta_key ); 
		
		if ( !empty($_GET['houserules']) || !empty($_POST['houserules']) )
			update_comment_meta( $comment_id, self::meta_key, '1' );
	}

	function admin_head() {

		echo '<style>.comment-houserules { display: none; } tr.unapproved .comment-houserules { display: inline }</style>' . '\n';

	}

	// add the Broke House Rules option to the list of comment options
	function comment_row_actions( $actions, $comment ) {
		if ( ! isset( $actions['approve'] ) )
			return $actions;

		$houserules = str_replace( 'action=approvecomment', 'action=approvecomment&amp;houserules=1', $actions['approve'] );
		preg_match( '/^(.*?>)/', $houserules, $matches );
		$houserules = str_replace( array( ':new=approved', ' vim-a' ), array( ':new=approved&houserules=1', '' ), $matches[1] );
		$houserules .= __( 'Broke House Rules', 'comment-houserules' ) . '</a>';

		$actions['approve'] .= '<span class="comment-houserules"> | ' . $houserules . '</span>';

		return $actions;
	}
	
	// if rule breaker comment then replace text
	function get_comment_text( $text , $comment ){
	
		if (get_comment_meta($comment->comment_ID , self::meta_key , true)) {
		
			return get_option ( 'hr_msg', '' );
			
		} else {
		
			return $text;
		}
	
	}

	// register new House Rules message option on discussion page 
	function hr_register_setting(){

    		register_setting(
      			'discussion',
      			'hr_msg',
       			'trim'
    		);
    
    		add_settings_field(
        		'houserules',
        		'Broke House Rules message',
        		array ( &$this , 'hr_show_settings' ),
        		'discussion',
        		'default',
        		array ( 'label_for' => 'hr_msg' )
    		);
	}

	// description for new HR option 
	function hr_description(){
    			
		echo '<p class="description">Enter message to be displayed in place of comment text</p>';
	}
	
	// get the option value
	function hr_show_settings( $args ){

	    	$data = esc_attr( get_option( 'hr_msg', '' ) );

    		printf(
        		'<textarea cols="50" name="hr_msg" id="hr_msg" class="large-text">'.$data.'</textarea>' ,
        		$data,
        		$args['label_for']
    		);
	}
}

new Plugin_Comment_Houserules();
?>